@@ -66,6 +66,15 @@ def wait_for(options = {}, &condition)
     true
 end
 
+def with_umask(umask, &block)
+    old_umask = File.umask(umask)
+    begin
+        block.call
+    ensure
+        File.umask(old_umask)
+    end
+end
+
 def valgrind_options
     opt = ARGV.find {|s| s.start_with?('--valgrind') }
     if opt == nil
@@ -179,6 +188,18 @@ def root_testenv(bindfs_args, options = {}, &block)
     end
 end
 
+# Like testenv but skips the test if not running as non-root.
+# TODO: make all tests runnable as root
+def nonroot_testenv(bindfs_args, options = {}, &block)
+    if Process.uid != 0
+        testenv(bindfs_args, options, &block)
+    else
+        puts "--- #{bindfs_args} ---"
+        puts "[  #{bindfs_args}  ]"
+        puts "SKIP (requires running as non-root)"
+    end
+end
+
 def umount_cmd
     if `which fusermount`.strip.empty?
     then 'umount'
